pub struct DropdownConfig {
pub title: String,
pub label: Vec<DropdownItem>,
pub background_color: DropdownColorScheme,
pub title_color: DropdownTitleColor,
pub labels_color: DropdownLabelsColor,
pub hover_color: DropdownHoverColor,
}Expand description
DropdownConfig holds the configuration for the dropdown menu, including
the list of dropdown items, background color, and text color.
Fields
title: Stringlabel: Vec<DropdownItem>background_color: DropdownColorSchemetitle_color: DropdownTitleColorlabels_color: DropdownLabelsColorhover_color: DropdownHoverColorTrait Implementations
Sourceimpl Clone for DropdownConfig
impl Clone for DropdownConfig
Sourcefn clone(&self) -> DropdownConfig
fn clone(&self) -> DropdownConfig
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl PartialEq for DropdownConfig
impl PartialEq for DropdownConfig
impl StructuralPartialEq for DropdownConfig